import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/popconfirm/vue';
import Popover from '@opentinyvue/vue-popover';
import Button from '@opentinyvue/vue-button';
import { iconSuccess, iconInfoSolid, iconWarning, iconError } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "inline-block",
    attrs: {
      "data-tag": "tiny-popconfirm"
    }
  }, [_c("tiny-popover", {
    ref: "popover",
    attrs: {
      "tiny_mode": "mobile-first",
      "placement": _vm.placement,
      "trigger": "manual",
      "width": _vm.width,
      "title": _vm.title,
      "popper-class": _vm.m("min-w-[theme(spacing.44)] max-w-[theme(spacing.96)]", _vm.customClass),
      "append-to-body": _vm.popperAppendToBody,
      "reference": _vm.reference
    },
    on: {
      "show": function show($event) {
        return _vm.handleEmit("show");
      },
      "hide": function hide($event) {
        return _vm.handleEmit("hide");
      }
    },
    scopedSlots: _vm._u([{
      key: "header",
      fn: function fn() {
        return [_c("div", {
          staticClass: "flex items-center leading-6 sm:pt-1",
          attrs: {
            "data-tag": "tiny-popconfirm-header"
          }
        }, [_vm.type ? _c(_vm.state.getIcon, {
          tag: "component",
          class: _vm.m("h-6 w-6 mr-2", {
            "fill-color-info-secondary": _vm.type === "info"
          }, {
            "fill-color-error": _vm.type === "error"
          }, {
            "fill-color-warning": _vm.type === "warning"
          }, {
            "fill-color-success": _vm.type === "success"
          })
        }) : _vm._e(), _c("div", {
          staticClass: "flex-auto"
        }, [_vm._v(_vm._s(_vm.title))])], 1)];
      },
      proxy: true
    }, {
      key: "default",
      fn: function fn() {
        return [_c("div", {
          attrs: {
            "data-tag": "tiny-popconfirm-content"
          }
        }, [_c("div", {
          staticClass: "sm:leading-6 sm:text-xs sm:text-color-text-secondary"
        }, [_vm._v(_vm._s(_vm.message))])])];
      },
      proxy: true
    }, {
      key: "footer",
      fn: function fn() {
        return [_c("div", {
          staticClass: "sm:pb-1",
          attrs: {
            "data-tag": "tiny-popconfirm-footer"
          }
        }, [_c("div", {
          staticClass: "hidden sm:flex mt-4 justify-end"
        }, [_vm._t("footer", function() {
          return [_vm.cancelButton ? _c("tiny-button", {
            staticClass: "mr-2 w-16",
            attrs: {
              "size": "mini",
              "tiny_mode": "mobile-first"
            },
            on: {
              "click": _vm.hide
            }
          }, [_vm._v(_vm._s(_vm.t("ui.buttonMessage.cancel")))]) : _vm._e(), _c("tiny-button", {
            staticClass: "w-16",
            attrs: {
              "size": "mini",
              "tiny_mode": "mobile-first",
              "type": "primary"
            },
            on: {
              "click": _vm.confirm
            }
          }, [_vm._v(_vm._s(_vm.t("ui.buttonMessage.confirm")))])];
        })], 2), _c("div", {
          staticClass: "flex sm:hidden text-base justify-center"
        }, [_vm._t("footer", function() {
          return [_vm.cancelButton ? _c("tiny-button", {
            attrs: {
              "custom-class": "flex-1 text-color-text-secondary",
              "tiny_mode": "mobile-first",
              "type": "text"
            },
            on: {
              "click": _vm.hide
            }
          }, [_vm._v(_vm._s(_vm.t("ui.buttonMessage.cancel")))]) : _vm._e(), _vm.cancelButton ? _c("span", {
            staticClass: "border-r border-r-color-border-separator"
          }) : _vm._e(), _c("tiny-button", {
            attrs: {
              "custom-class": "flex-1 text-color-brand tiny-modal-mf-button",
              "tiny_mode": "mobile-first",
              "type": "text"
            },
            on: {
              "click": _vm.confirm
            }
          }, [_vm._v(_vm._s(_vm.t("ui.buttonMessage.confirm")))])];
        })], 2)])];
      },
      proxy: true
    }, {
      key: "reference",
      fn: function fn() {
        return [_c("div", {
          staticClass: "inline-block",
          on: {
            "click": function click($event) {
              return _vm.show("click");
            },
            "mouseover": function mouseover($event) {
              return _vm.show("hover");
            }
          }
        }, [_vm._t("reference")], 2)];
      },
      proxy: true
    }], null, true),
    model: {
      value: _vm.state.showPopover,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "showPopover", $$v);
      },
      expression: "state.showPopover"
    }
  })], 1);
};
var staticRenderFns = [];
var $constants = {
  ICON_MAP: {
    success: "icon-success",
    error: "icon-error",
    info: "icon-info-solid",
    warning: "icon-warning"
  }
};
var __vue2_script = defineComponent({
  name: $prefix + "Popconfirm",
  components: {
    TinyPopover: Popover,
    TinyButton: Button,
    IconSuccess: iconSuccess(),
    IconInfoSolid: iconInfoSolid(),
    IconWarning: iconWarning(),
    IconError: iconError()
  },
  props: {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    message: String,
    customClass: String,
    trigger: {
      type: String,
      default: "hover",
      validator: function validator(value) {
        return ~["click", "hover"].indexOf(value);
      }
    },
    cancelButton: {
      type: Boolean,
      default: true
    },
    closeOnClickOutside: {
      type: Boolean,
      default: true
    },
    title: String,
    placement: {
      type: String,
      default: "top"
    },
    width: {
      type: [String, Number],
      default: ""
    },
    type: [String, Object],
    reference: {},
    events: Object,
    popperAppendToBody: {
      type: Boolean,
      default: true
    }
  },
  emits: ["hide", "show", "confirm", "handleEmit"],
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
